@@ -6,15 +6,15 @@ from pequod_cli.replicator import FileReplicator
 
 
 class Context:
-    def __init__(self, config_file, cluster, endpoints: dict, credentials):
+    def __init__(self, config_file, cluster, endpoints: dict, credentials: dict, cacert: str):
         self.config_file = config_file
         self.cluster = cluster
         self.endpoints = endpoints
 
-        self.auth = AuthService(endpoints, credentials)
-        self.replicator = FileReplicator(endpoints, credentials)
-        self.manager = CoreManager(endpoints, credentials)
-        self.registry = ApplicationRegistry(endpoints, credentials)
-        self.controller = ClusterController(endpoints, credentials)
+        self.auth = AuthService(endpoints, credentials, cacert)
+        self.replicator = FileReplicator(endpoints, credentials, cacert)
+        self.manager = CoreManager(endpoints, credentials, cacert)
+        self.registry = ApplicationRegistry(endpoints, credentials, cacert)
+        self.controller = ClusterController(endpoints, credentials, cacert)
 
         self.all_core_services = [self.auth, self.replicator, self.manager, self.registry, self.controller]
