@@ -1,3 +1,4 @@
+import fnmatch
 from operator import itemgetter
 import os
 import tarfile
@@ -34,19 +35,27 @@ def nodes(ctx):
         print_table('name mac ipv4 ipv6 template_name template_version reboot maintenance'.split(), rows)
 
 
+def get_matching_node_names(manager, pattern):
+    data = manager.get('/nodes')
+    names = [row['name'] for row in data['nodes']]
+    matching_node_names = fnmatch.filter(names, pattern)
+    return sorted(matching_node_names)
+
+
 @nodes.command()
-@click.argument('node_name')
+@click.argument('node_name_pattern')
 @click.pass_obj
-def reboot(ctx, node_name):
+def reboot(ctx, node_name_pattern):
     """
-    Reboot a cluster app node
+    Reboot one or more cluster app node(s)
     """
-    action('Rebooting {}..'.format(node_name))
-    data = {'maintenance': False,
-            'reboot': True
-            }
-    ctx.manager.patch('/nodes/{}'.format(node_name), data=data)
-    ok()
+    for node_name in get_matching_node_names(ctx.manager, node_name_pattern):
+        action('Rebooting {}..'.format(node_name))
+        data = {'maintenance': False,
+                'reboot': True
+                }
+        ctx.manager.patch('/nodes/{}'.format(node_name), data=data)
+        ok()
 
 
 def parse_version(v):
@@ -54,40 +63,41 @@ def parse_version(v):
 
 
 @nodes.command()
-@click.argument('node_name')
+@click.argument('node_name_pattern')
 @click.argument('key_value', nargs=-1)
 @click.pass_obj
-def update(ctx, node_name, key_value):
+def update(ctx, node_name_pattern, key_value):
     """
     Update node configuration (e.g. "template_version")
     """
-    data = ctx.manager.get('/nodes/{}'.format(node_name))
-    del data['reboot']
-    del data['maintenance']
-    for pair in key_value:
-        try:
-            key, val = pair.split('=', 1)
-        except:
-            raise click.UsageError('Key pairs need to be specified as KEY=VAL')
-        if key not in data:
-            raise click.UsageError('Invalid key: "{}" is not allowed'.format(key))
-        if key == 'template_version' and val == 'latest':
-            # special case: find out latest template and use it
-            latest_version = '0'
-            for row in ctx.manager.get_templates():
-                if row['template_name'] == data['template_name']:
-                    # TODO: only supports numeric versions right now :-P
-                    try:
-                        if parse_version(row['template_version']) > parse_version(latest_version):
-                            latest_version = row['template_version']
-                    except ValueError:
-                        # ignore non-int versions
-                        pass
-            val = latest_version
-        data[key] = val
-    action('Updating {}..'.format(node_name))
-    ctx.manager.put('/nodes/{}'.format(node_name), data=data)
-    ok()
+    for node_name in get_matching_node_names(ctx.manager, node_name_pattern):
+        data = ctx.manager.get('/nodes/{}'.format(node_name))
+        del data['reboot']
+        del data['maintenance']
+        for pair in key_value:
+            try:
+                key, val = pair.split('=', 1)
+            except:
+                raise click.UsageError('Key pairs need to be specified as KEY=VAL')
+            if key not in data:
+                raise click.UsageError('Invalid key: "{}" is not allowed'.format(key))
+            if key == 'template_version' and val == 'latest':
+                # special case: find out latest template and use it
+                latest_version = '0'
+                for row in ctx.manager.get_templates():
+                    if row['template_name'] == data['template_name']:
+                        # TODO: only supports numeric versions right now :-P
+                        try:
+                            if parse_version(row['template_version']) > parse_version(latest_version):
+                                latest_version = row['template_version']
+                        except ValueError:
+                            # ignore non-int versions
+                            pass
+                val = latest_version
+            data[key] = val
+        action('Updating {}..'.format(node_name))
+        ctx.manager.put('/nodes/{}'.format(node_name), data=data)
+        ok()
 
 
 @manager.group(invoke_without_command=True, cls=AliasedGroup)
@@ -208,9 +218,11 @@ def networks(ctx):
     rows = []
     for row in data['networks']:
         row['ipv6_subnet'] = IPNetwork('{}/{}'.format(row['ipv6_subnet_ip'], row['ipv6_subnet_prefixlen']))
+        row['ipv6_routes'] = ', '.join([
+            '{destination_ip}/{destination_prefixlen} via {gateway}'.format(**r) for r in row['ipv6_routes']])
         rows.append(row)
     rows.sort(key=itemgetter('zone_name'))
-    print_table('zone_name location_name ipv6_subnet ipv6_gateway ipv6_dns'.split(), rows)
+    print_table('zone_name location_name ipv6_subnet ipv6_gateway ipv6_dns ipv6_routes'.split(), rows)
 
 
 @manager.group(invoke_without_command=True, cls=AliasedGroup)
